geowatch.cli.queue\_cli.prepare\_teamfeats module
=================================================

.. automodule:: geowatch.cli.queue_cli.prepare_teamfeats
   :members:
   :undoc-members:
   :show-inheritance:
